@@ -1576,7 +1576,7 @@ class In(Predicate):
 
 
 class Interval(Expression):
-    arg_types = {"this": True, "unit": True}
+    arg_types = {"this": True, "unit": False}
 
 
 class TryCast(Cast):
@@ -1832,6 +1832,10 @@ class Quantile(AggFunc):
     arg_types = {"this": True, "quantile": True}
 
 
+class Reduce(Func):
+    arg_types = {"this": True, "initial": True, "merge": True, "finish": True}
+
+
 class RegexpLike(Func):
     arg_types = {"this": True, "expression": True}
 
