@@ -343,9 +343,6 @@ class Generator:
             ),
         )
 
-    def exists_sql(self, expression):
-        return f"EXISTS {self.wrap(expression)}"
-
     def filter_sql(self, expression):
         this = self.sql(expression, "this")
         where = self.sql(expression, "expression")[1:]  # where has a leading space
@@ -459,13 +456,20 @@ class Generator:
     def join_sql(self, expression):
         side = self.sql(expression, "side").upper()
         kind = self.sql(expression, "kind").upper()
-        op_sql = self.seg(" ".join(op for op in [side, kind, "JOIN"] if op))
+        op_sql = self.seg(" ".join(op for op in (side, kind, "JOIN") if op))
         on_sql = self.sql(expression, "on")
+        using = expression.args.get("using")
+
+        if not on_sql and using:
+            on_sql = csv(*(self.sql(column) for column in using))
 
         if on_sql:
             on_sql = self.indent(on_sql, skip_first=True)
             space = self.seg(" " * self.pad) if self.pretty else " "
-            on_sql = f"{space}ON {on_sql}"
+            if using:
+                on_sql = f"{space}USING ({on_sql})"
+            else:
+                on_sql = f"{space}ON {on_sql}"
 
         expression_sql = self.sql(expression, "expression")
         this_sql = self.sql(expression, "this")
@@ -623,6 +627,15 @@ class Generator:
 
         return f"{self.sql(expression, 'this')}[{expressions}]"
 
+    def all_sql(self, expression):
+        return f"ALL{self.wrap(expression)}"
+
+    def any_sql(self, expression):
+        return f"ANY{self.wrap(expression)}"
+
+    def exists_sql(self, expression):
+        return f"EXISTS{self.wrap(expression)}"
+
     def case_sql(self, expression):
         this = self.indent(self.sql(expression, "this"), skip_first=True)
         this = f" {this}" if this else ""
@@ -639,14 +652,6 @@ class Generator:
         statement = f"CASE{this}{ifs}{self.seg('END')}"
         return statement
 
-    def decimal_sql(self, expression):
-        args = ", ".join(
-            arg.args.get("this")
-            for arg in [expression.args.get("precision"), expression.args.get("scale")]
-            if arg
-        )
-        return f"DECIMAL({args})"
-
     def extract_sql(self, expression):
         this = self.sql(expression, "this")
         expression_sql = self.sql(expression, "expression")
